package com.admin.major.mapper;

import java.util.List;
import com.admin.major.domain.ScheduleArrange;

/**
 * 日程安排Mapper接口
 * 
 * @author zewei
 * @date 2022-05-06
 */
public interface ScheduleArrangeMapper 
{
    /**
     * 查询日程安排
     * 
     * @param scheduleId 日程安排主键
     * @return 日程安排
     */
    public ScheduleArrange selectScheduleArrangeByScheduleId(Long scheduleId);

    /**
     * 查询日程安排列表
     * 
     * @param scheduleArrange 日程安排
     * @return 日程安排集合
     */
    public List<ScheduleArrange> selectScheduleArrangeList(ScheduleArrange scheduleArrange);

    /**
     * 新增日程安排
     * 
     * @param scheduleArrange 日程安排
     * @return 结果
     */
    public int insertScheduleArrange(ScheduleArrange scheduleArrange);

    /**
     * 修改日程安排
     * 
     * @param scheduleArrange 日程安排
     * @return 结果
     */
    public int updateScheduleArrange(ScheduleArrange scheduleArrange);

    /**
     * 删除日程安排
     * 
     * @param scheduleId 日程安排主键
     * @return 结果
     */
    public int deleteScheduleArrangeByScheduleId(Long scheduleId);

    /**
     * 批量删除日程安排
     * 
     * @param scheduleIds 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteScheduleArrangeByScheduleIds(Long[] scheduleIds);
}
